tsseg.algorithms.pelt package
=============================

Exact CPD with optimal pruning rule, O(n) average time.

| **Type:** change point detection
| **Supervision:** fully unsupervised (penalty-based)
| **Scope:** multiple cost models

**Implementation:** Vendored from ruptures v1.1.8. BSD 2-Clause.

**Reference:** Killick, Fearnhead & Eckley (2012), JASA.

Submodules
----------

tsseg.algorithms.pelt.detector module
-------------------------------------

.. automodule:: tsseg.algorithms.pelt.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.pelt
   :members:
   :show-inheritance:
   :undoc-members:
